@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 '''isort:skip_file'''
 __title__ = 'cpenv'
-__version__ = '0.5.5'
+__version__ = '0.5.14'
 __author__ = 'Dan Bradham'
 __email__ = 'danielbradham@gmail.com'
 __url__ = 'http://github.com/cpenv/cpenv'
@@ -11,11 +11,15 @@ __description__ = 'Cross-platform Python environment management.'
 
 # Local imports
 from .api import *
+from .module import *
 from .repos import *
 from .reporter import *
 from .resolver import *
 from .versions import *
 from . import vendor
+from . import paths
+from . import compat
+from . import mappings
 
 
 # Initialize cpenv
